<?php
//
// N.B. Enable openssl and soap in php.ini!
//
$ANTIPLAGIAT_URI = 'https://testapi.antiplagiat.ru';


// Create service client(https)
$LOGIN = "testapi@antiplagiat.ru";
$PASSWORD = "testapi";
$COMPANY_NAME = 'testapi';
$APICORP_ADDRESS = 'api.antiplagiat.ru:44902';

$oldValue = libxml_disable_entity_loader( false );
$client = new SoapClient("https://$APICORP_ADDRESS/apiCorp/$COMPANY_NAME?singleWsdl",
                         array("trace"=>1,
                               "login"=>$LOGIN,
                               "password"=>$PASSWORD,
                               "soap_version" => SOAP_1_1,
                               "features" => SOAP_SINGLE_ELEMENT_ARRAYS,
                        ));
libxml_disable_entity_loader( $oldValue );


function soap_debug($client){
    $requestHeaders = $client->__getLastRequestHeaders();
    $request = $client->__getLastRequest();
    $responseHeaders = $client->__getLastResponseHeaders();
    $response = $client->__getLastResponse();

    // print("requestheaders:");
    // print($requestHeaders);
    // print("request:");
    // print($request);
    // print("responseHeaders:");
    // print($responseHeaders);
    // print("response:");
    // print($response);
}

// Preparation of the description of the uploaded file.
function get_doc_data($filepath) {
    return array (
        "Data" => file_get_contents($filepath),
        "FileName" => basename($filepath),
        "FileType" => "." . substr(strrchr($filepath, "."), 1),
        "ExternalUserID" => "ivanov" // the field must be filled in with the ID of the real user in the external system;
    );
}

// An example of the most common scenario of the document check.
function simple_check($filepath) {
    global $client;
    global $COMPANY_NAME;
    // Description of the uploaded file
    $data = get_doc_data($filepath);
	$attributes = array(
		"DocumentDescription" => array(
			"Authors" => array (
				"AuthorName" => array (
					"OtherNames" => "Ivan",
					"Surname" => "Ivanov",
					"PersonIDs" => array(
						"CustomID" => "original"
					)
				)

			)
		)
	);
    // File upload
    $uploadResult = $client->UploadDocument(array("data"=>$data, "attributes"=>$attributes));

    // Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    $id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;

	// Send to check using all available searching modules 
    $client->CheckDocument(array("docId" => $id));
	// Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
    // $client->CheckDocument(array("docId" => $id, "checkServicesList" => array($COMPANY_NAME, "wikipedia")));

    // Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep($status->GetCheckStatusResult->EstimatedWaitTime * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $id));
    }

    // Check failed
    if ($status->GetCheckStatusResult->Status === "Failed")
    {
        echo("While checking the document an error occurred:" + $status->GetCheckStatusResult->FailDetails);
        return;
    }

    // Get brief report
    $report = $client->GetReportView(array("docId" => $id));

    foreach ($report->GetReportViewResult->CheckServiceResults as $checkService) {
        // Information about each search module 
        echo("Check service: $checkService->CheckServiceName Score.White=" .
             $checkService->ScoreByReport->Legal . "% Score.Black=" .
             $checkService->ScoreByReport->Plagiarism . "% Score.SelfCite=" .
             $checkService->ScoreByReport->SelfCite . "%\n");
        if (isset($checkService->Sources)) {
            foreach($checkService->Sources as $source) {
                // Information about each found source
                echo("\t" . $source->SrcHash .": Score=" . $source->ScoreByReport . "% (".
                     $source->ScoreBySource . "%), Name='".$source->Name."' ".
                     "Author='".$source->Author."' " .
                     "Url='".$source->Url."'\n");
            }
        }
    }

    // Get full report
    $fullReport = $client->GetReportView(array("docId" => $id, "options" => array("FullReport" => true, "NeedText" => true, "NeedStats" => true, "NeedAttributes" => true)));

    if (isset($fullReport->GetReportViewResult->Details->CiteBlocks)) {
        // Find the biggest block of reuses and display it 

        $maxlen = max(array_map(function($c) { return $c->Length; }, $fullReport->GetReportViewResult->Details->CiteBlocks));

        foreach ($fullReport->GetReportViewResult->Details->CiteBlocks as $block)
            if ($block->Length === $maxlen)
                echo("Max block length=".$block->Length." Source=".
                      $block->SrcHash." text:\n".
                      ($fullReport->GetReportViewResult->Details->Text.substr($block->Offset, min($block->Length, 200)))."...\n");
    }
	echo("Author Surname = ".$fullReport->GetReportViewResult->Attributes->DocumentDescription->Authors->AuthorName[0]->Surname." OtherNames=".
		$fullReport->GetReportViewResult->Attributes->DocumentDescription->Authors->AuthorName[0]->OtherNames." CustomID=".
		$fullReport->GetReportViewResult->Attributes->DocumentDescription->Authors->AuthorName[0]->PersonIDs->CustomID);	
}

// Enumeration of all received reports
function enumerate_reports() {
    global $client;
    global $ANTIPLAGIAT_URI;

    echo("Enumerate Reports\n");
    // Selecting user documents with an ID in the external system "ivanov"
    $opts = array("ExternalUserID" => 'ivanov', "Count" => 10, "Skip" => 0);
    // Get the first pack of reports, sorting is always reverse chronological, the report of the last uploaded document will be the first
    $reps = $client->EnumerateReportInfos(array("options" => $opts));
    // Report counter
    $i = 0;
    // The EnumerateReportInfos function returns the results of the check in pack. An empty pack means that the search has ended.
    while (isset($reps->EnumerateReportInfosResult)) {
        $reps = $reps->EnumerateReportInfosResult;
        foreach ($reps as $info) {
            $i++;
            // We output the number in order, the name of the document and the status of the last report
            printf("%d  DocName: %s\n   Status: %s\n", $i, $info->DocumentInfo->Attributes->Name, $info->CheckStatus->Status);
            // If the check is completed we display percent of non-originality and link to the report.
            if ($info->CheckStatus->Status === 'Ready') {
                printf("   %s, %s\n", 100 - $info->CheckStatus->Summary->DetailedScore->Unknown, $ANTIPLAGIAT_URI.$info->CheckStatus->Summary->ReportWebId);
            }
        }
        // Get the next pack of reports
        $opts["Skip"] = $i;
        $reps = $client->EnumerateReportInfos(array("options" => $opts));
    }
}

// Enumeration of all uploaded documents
function enumerate_documents() {
    global $client;

    echo("Enumerate Documents\n");

    // Get the first pack of documents
    $docs = $client->EnumerateDocuments();

    // Document counter
    $i = 0;
    // The EnumerateDocuments function returns IDs in packs. An empty pack means that the search has ended.
    while (isset($docs->EnumerateDocumentsResult)) {
        $docs = $docs->EnumerateDocumentsResult;
        foreach($docs as $id) {
            $i++;
			// We add every fifth document to the index
            if ($i % 5 === 0)
                $client->SetIndexState(array("docId" => $id, "indexState" => 'Indexed'));
            // We add an attribute to every third document
            if ($i % 3 === 0) {
                $client->UpdateDocumentAttributes(array("docId"=>$id, "attributes"=>array("Custom"=>array("AttrName"=>"docnum", "AttrValue"=>$i.""))));
            }
        }
        $docs = $client->EnumerateDocuments(array("afterDocId" => end($docs)));
    }
    echo("Total documents count: $i (".$client->GetCompanyStats()->GetCompanyStatsResult->TotalCount.")");
}

// Enumeration of all documents added to the index
function enumerate_index() {
    global $client;

    echo("EnumerateIndex\n");
    // When calling EnumerateDocuments, the options indicate that only documents added to the index are required
    $docs = $client->EnumerateDocuments(array("options" => array("AddedToIndex" => true)))->EnumerateDocumentsResult;
    // Document counter
    $i = 0;
    // The EnumerateDocuments function returns IDs in packs. An empty pack means that the enumeration has ended.
    while (count($docs) > 0) {
        foreach($docs as $id) {
            $i++;
            // We delete every second document from the index
            if ($i % 2 === 0)
                $client->SetIndexState(array("docId" => $id, "indexState" => 'None'));
        }
        // Get next pack of document IDs
        $docs = $client->EnumerateDocuments(array("afterDocId"=> end($docs), "options" => array("AddedToIndex" => true)))->EnumerateDocumentsResult;
    }
    echo("Total indexed documents count: $i (".$client->GetCompanyStats()->GetCompanyStatsResult->AddedToIndexCount.")\n");
}

// Check the document, get link to the report on the "Antiplagiat" website
function get_web_report($filepath) {
    global $client;
    global $COMPANY_NAME;
    global $ANTIPLAGIAT_URI;
    // Description of the uploaded file
    $data = get_doc_data($filepath);
    // File upload
    $uploadResult = $client->UploadDocument(array("data"=>$data));

    // Document ID. If the archive is not being uploaded, then the list of uploaded documents will consist of one element.
    $id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;

    // Send to check using all available searching modules 
    $client->CheckDocument(array("docId" => $id));
	// Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
    // $client->CheckDocument(array("docId" => $id, "checkServicesList" => array($COMPANY_NAME, "wikipedia")));

    // Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep($status->GetCheckStatusResult->EstimatedWaitTime * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $id));
    }

    // Check failed
    if ($status->GetCheckStatusResult->Status === "Failed")
    {
        echo("При проверке документа произошла ошибка:" + $status->GetCheckStatusResult->FailDetails);
        return;
    }

    echo("Full Report: $ANTIPLAGIAT_URI".$status->GetCheckStatusResult->Summary->ReportWebId."\n");
    echo("Short Report: $ANTIPLAGIAT_URI".$status->GetCheckStatusResult->Summary->ShortReportWebId."\n");
    echo("Readonly Report: $ANTIPLAGIAT_URI".$status->GetCheckStatusResult->Summary->ReadonlyReportWebId."\n");
}

# Methods for working with folders.
function folders_methods($filepath1, $filepath2) {
    global $client;

    echo("FoldersMethods\n");

    $email = "testapi@antiplagiat.ru";

    // User creates folder "New Folder"
    $folderId = $client->AddFolder(array("email" => $email, "name" => "New Folder"))->AddFolderResult;

    // User renames it to "Documents"
    $client->RenameFolder(array("email" => $email, "folderId" => $folderId, "name" => "Documents"));

    // Description of folder creation options
    $folderOptions = array("ParentId" => $folderId);

    // User creates in the folder "Documents" a new folder "Important"
    $importantFolderId = $client->AddFolder(array("email" => $email, "name" => "Important", "options" => $folderOptions))->AddFolderResult;

    // Description of the first uploaded file
    $data1 = get_doc_data($filepath1);

    // Description of the first file upload options
    $uploadOptions1 = array("FolderId" => $folderId, "FromUser" => $email);

    // User uploads file tt1.txt to the folder "Documents"
    $client->UploadDocument(array("data" => $data1, "options" => $uploadOptions1));

    // Description of the second uploaded file
    $data2 = get_doc_data($filepath2);

    // Description of the second file upload options
    $uploadOptions2 = array("FolderId" => $importantFolderId, "FromUser" => $email);

    // User uploads file tt2.txt to the folder "Important"
    $client->UploadDocument(array("data" => $data2, "options" => $uploadOptions2));

    // User creates folder "Trash"
    $trashFolderId = $client->AddFolder(array("email" => $email, "name" => "Trash"))->AddFolderResult;

    // Description of documents enumeration options
    $enumerateDocumentsOptions1 = array("FromUser" => $email);

    // User gets IDs of all his documents
    $docs = $client->EnumerateDocuments(array("options" => $enumerateDocumentsOptions1))->EnumerateDocumentsResult;

    // User moves his documents to the folder "Trash"
    $client->MoveDocuments(array("email" => $email, "folderId" => $trashFolderId, "docIds" => $docs));

    // User gets a folder tree
    $folderTree = $client->GetFolders(array("email" => $email))->GetFoldersResult;

    echo("\nFolderTree:\n");

    echo("\nTop level:\n");
    echo("Name: ");
    echo($folderTree->Name);

    echo("\n\nNext level:\n");

    foreach($folderTree->Children as $folder)
    {
        foreach($folder as $item)
        {
            echo("Name: ");
            echo($item->Name);
            echo("\n");
        }
    }

    echo("\nGet documents from \"Trash\"");

    // Description of documents enumeration options
    $enumerateDocumentsOptions2 = array("InStorage" => false, "FolderId" => $trashFolderId, "FromUser" => $email);

    // User gets his documents from the folder "Trash"
    $trashDocs = $client->EnumerateDocuments(array("options" => $enumerateDocumentsOptions2))->EnumerateDocumentsResult;

    echo("\nDocuments count: ");
    echo(count($trashDocs));
    echo("\n");

    // User deletes folders "Documents" and "Trash"
    $client->DeleteFolder(array("email" => $email, "folderId" => $folderId));
    $client->DeleteFolder(array("email" => $email, "folderId" => $trashFolderId));
}

// Methods for working with the storage.
function storage_methods($filepath1, $filepath2) {
    global $client;

    echo("StorageMethods\n");

    // User creates folder "New Folder" in the storage
    $folderId = $client->AddFolder(array("name" => "New Folder"))->AddFolderResult;

    // User renames it into "Documents"
    $client->RenameFolder(array("folderId" => $folderId, "name" => "Documents"));

    // Description of folder creation options
    $folderOptions = array("ParentId" => $folderId);

    // User creates new folder "Important" in the folder "Documents"
    $importantFolderId = $client->AddFolder(array("name" => "Important", "options" => $folderOptions))->AddFolderResult;

    // Description of the first uploaded file
    $data1 = array("Data" => file_get_contents($filepath1),
                  "FileName" => basename($filepath1),
                  "FileType" => "." . substr(strrchr($filepath1, "."), 1));

    // Description of the first file upload options
    $uploadOptions1 = array("FolderId" => $folderId, "ToStorage" => true);

    // User uploads file tt1.txt to the folder "Documents"
    $client->UploadDocument(array("data" => $data1, "options" => $uploadOptions1));

    // Description of the second uploaded file
    $data2 = array("Data" => file_get_contents($filepath2),
                  "FileName" => basename($filepath2),
                  "FileType" => "." . substr(strrchr($filepath2, "."), 1));

    // Description of the second file upload options
    $uploadOptions2 = array("FolderId" => $importantFolderId, "ToStorage" => true);

    // User uploads file tt2.txt to the folder "Important"
    $client->UploadDocument(array("data" => $data2, "options" => $uploadOptions2));

    // User creates folder "Trash" in the storage
    $trashFolderId = $client->AddFolder(array("name" => "Trash"))->AddFolderResult;

    // The user gets the IDs of all documents from the storage
    $docs = $client->EnumerateDocuments(array("options" => array("InStorage" => true)))->EnumerateDocumentsResult;

    // The user moves all documents to the folder "Trash"
    $client->MoveDocuments(array("folderId" => $trashFolderId, "docIds" => $docs));

    // The user gets a tree of storage folders
    $folderTree = $client->GetFolders(null)->GetFoldersResult;

    echo("\nFolderTree:\n");

    echo("\nTop level:\n");
    echo("Name: ");
    echo($folderTree->Name);

    echo("\n\nNext level:\n");

    foreach($folderTree->Children as $folder)
    {
        foreach($folder as $item)
        {
            echo("Name: ");
            echo($item->Name);
            echo("\n");
        }
    }

    echo("\nGet documents from \"Trash\"");

    // Description of documents enumeraion options
    $enumerateDocumentsOptions = array("InStorage" => true, "FolderId" => $trashFolderId);

    // User gets the documents from the folder "Trash" in the storage
    $trashDocs = $client->EnumerateDocuments(array("options" => $enumerateDocumentsOptions))->EnumerateDocumentsResult;

    echo("\nDocuments count: ");
    echo(count($trashDocs));
    echo("\n");

    // User deletes folders "Documents" and "Trash"
    $client->DeleteFolder(array("folderId" => $folderId));
    $client->DeleteFolder(array("folderId" => $trashFolderId));
}

// Getting information about the current tariff.
function get_tariff_info() {
  global $client;

  echo("GetTariffInfo\n");

  // Get information about the current tariff
  $tariffInfo = $client->GetTariffInfo()->GetTariffInfoResult;

    echo("Tariff name: ");
    echo($tariffInfo->Name);
    echo("\n");

    echo("Tariff subscription date: ");
    echo($tariffInfo->SubscriptionDate);
    echo("\n");

    echo("Tariff expiration date: ");
    echo($tariffInfo->ExpirationDate);
    echo("\n");

    echo("Tariff total checks count: ");
    echo($tariffInfo->TotalChecksCount);
    echo("\n");

    echo("Tariff remained checks count: ");
    echo($tariffInfo->RemainedChecksCount);
    echo("\n");

    echo("\nAvailable check services:");

    foreach($tariffInfo->CheckServices as $checkServices)
    {
        foreach($checkServices as $checkService)
        {
            echo("\n");
            echo($checkService->Code);
            echo("\t");
            echo($checkService->Description);
        }
    }
}

// Check the document, get the link to the pdf-report on the "Antiplagiat" site
function export_report_to_pdf($filepath){
	global $client;
    global $COMPANY_NAME;
	global $ANTIPLAGIAT_URI;
    // Description of the file being uploaded
    $data = get_doc_data($filepath);

	// File uploading
    $uploadResult = $client->UploadDocument(array("data"=>$data));

	// Document ID.  If the archive is not being downloaded, then the list of downloaded documents will consist of one element
	$id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;

	// Send to check using all available searching modules 
    $client->CheckDocument(array("docId" => $id));
	// Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
    // $client->CheckDocument(array("docId" => $id, "checkServicesList" => array($COMPANY_NAME, "wikipedia")));

	// Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep(max($status->GetCheckStatusResult->EstimatedWaitTime, 10) * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $id));
    }

	// Check failed
    if ($status->GetCheckStatusResult->Status === "Failed")
    {
        echo("При проверке документа произошла ошибка:" + $status->GetCheckStatusResult->FailDetails);
        return;
    }

    // Request generation of the last full report in PDF format.
    $exportReportInfo = $client->ExportReportToPdf(array("docId" => $id));

    // The cycle of waiting for the report generation
    while ($exportReportInfo->ExportReportToPdfResult->Status === "InProgress")
    {
        sleep(max($exportReportInfo->ExportReportToPdfResult->EstimatedWaitTime, 10) * 0.1);
        $exportReportInfo = $client->ExportReportToPdf(array("docId" => $id));
    }

    // Report generation failed.
    if ($exportReportInfo->ExportReportToPdfResult->Status === "Failed")
    {
        echo("An error occured while generating the report:" + $exportReportInfo->ExportReportToPdfResult->FailDetails);
        return;
    }

	// Get a link to the report on the "Antiplagiat" website
    // Please pay attention that it is not guaranteed that this link will work forever, it may stop working at any time,
    // therefore, you cannot give it to the user. You need to download a pdf for yourself and then manage its lifetime
    $downloadLink =  join("", array($ANTIPLAGIAT_URI, $exportReportInfo->ExportReportToPdfResult->DownloadLink));
	echo("PDF full report (number = " + $exportReportInfo->ExportReportToPdfResult->ReportNum + "):" + $downloadLink);

	$options = array("ReportNum" => 1,
	                 "ShortReport" => true);

    // Request the generation of a PDF report with the specified options.
    $exportReportInfo = $client->ExportReportToPdf(array("docId" => $id, "options" => $options));

	// The cycle of waiting for report generation
    while ($exportReportInfo->ExportReportToPdfResult->Status === "InProgress")
    {
        sleep(max($exportReportInfo->ExportReportToPdfResult->EstimatedWaitTime, 10) * 0.1);
        $exportReportInfo = $client->ExportReportToPdf(array("docId" => $id, "options" => $options));
    }

	// Report generation failed.
    if ($exportReportInfo->ExportReportToPdfResult->Status === "Failed")
    {
        echo("При формировании отчета произошла ошибка:" + $exportReportInfo->ExportReportToPdfResult->FailDetails);
        return;
    }

	// Get a link to the report on the "Antiplagiat" website
    // Please pay attention that it is not guaranteed that this link will work forever, it may stop working at any time,
    // therefore, you cannot give it to the user. You need to download a pdf for yourself and then manage its lifetime
    $downloadLink =  join("", array($ANTIPLAGIAT_URI, $exportReportInfo->ExportReportToPdfResult->DownloadLink));
	echo("PDF full report (number = " + $exportReportInfo->ExportReportToPdfResult->ReportNum + "):" + $downloadLink);
}

// An example of getting a certificate for the checked file
function get_verification_report($filepath)
{
    global $client;

    // Description of the file being uploaded
    $data = get_doc_data($filepath);
    // File uploading
    $uploadResult = $client->UploadDocument(array("data"=>$data));

    // Document ID. If the archive is not being downloaded, then the list of downloaded documents will consist of one element
    $id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;

    // Send to check using all available searching modules 
    $client->CheckDocument(array("docId" => $id));
	// Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
    // $client->CheckDocument(array("docId" => $id, "checkServicesList" => array($COMPANY_NAME, "wikipedia")));

    // Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep($status->GetCheckStatusResult->EstimatedWaitTime * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $id));
    }

    // Check failed
    if ($status->GetCheckStatusResult->Status === "Failed")
    {
        echo("An error occurred while checking the document:" + $status->GetCheckStatusResult->FailDetails);
        return;
    }

    //You can download certificate with or without filled fields
    //Without filled fields
    //$report = $client->GetVerificationReport(array("docId" => $id));

    //To fill the fields, you need to create a certificate options object with the desired property values 
    $options = array("Author" 		=> "Ivanov I.I.", // Full name of the document's author
    "Department" 	=> "Faculty of General and Applied Physics", // Faculty (structural subdivision)
    "ShortReport" 	=> true, //  Is a link to the summary brief required? (qr code)
    "Type" 			=> "Thesis", // Type of work
    "Verifier" 		=> "Petrov P.P.", // Full name of the verifier
    "Work" 			=> "Coherent spin dynamics of a two-dimensional electron gas"  // Name of the work
    );

    $verRepFileName = get_ver_rep_filename($id, $options);

    //With filled fields
    $report = $client->GetVerificationReport(array("docId" => $id, "options" => $options));

    //writing to file
    $objData = serialize( $report);
    $savePath = $verRepFileName;
        $fp = fopen($savePath, "w");
        fwrite($fp, $objData);
        fclose($fp);
}

//example of getting a bibliography from file
function get_bibliography($filepath) {
    global $client;
	
    // Description of the file being uploaded
    $data = get_doc_data($filepath);
    // File uploading
    $uploadResult = $client->UploadDocument(array("data" => $data));

    // Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    $id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;
	
    $status = $client->GetTextExtractStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetTextExtractStatusResult->TextStatus === "InProgress")
    {
        sleep(1);
        $status = $client->GetTextExtractStatus(array("docId" => $id));
    }
	
    // Uploading failed
    if ($status->GetTextExtractStatusResult->TextStatus === "Failed")
    {
        echo("An error occurred while loading the document" );
        return;
    }
	
	$result = $client->GetBibliographyText(array("docId" => $id))->GetBibliographyTextResult;
    if ($result->Status !== "Ok")
    {
        echo("Bibliography was not extracted" );
        return;
    }
	foreach ($result->MarkedText as $texts)
	{
        foreach($texts as $text)
        {
			echo($text);
		}
	}    
}

function selfcite_check($filepath) {
    global $client;
    global $COMPANY_NAME;
    // Description of the file being uploaded
    $data = get_doc_data($filepath);
	$attributes = array(
		"DocumentDescription" => array(
			"Authors" => array (
				"AuthorName" => array (
					"OtherNames" => "Ivan",
					"Surname" => "Ivanov",
					"PersonIDs" => array(
						"CustomID" => "original"
					)
				)

			)
		)
	);
	$opts = array(
		"AddToIndex" => true
	);
    // File uploading
    $uploadResult = $client->UploadDocument(array("data"=>$data, "attributes"=>$attributes, "options"=>$opts));

    // Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    $id = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;

	// Send to check using all available searching modules
    $client->CheckDocument(array("docId" => $id));

    // Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $id));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep($status->GetCheckStatusResult->EstimatedWaitTime * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $id));
    }

    // Check failed
    if ($status->GetCheckStatusResult->Status === "Failed")
    {
        echo("An error occurred while checking the document:" + $status->GetCheckStatusResult->FailDetails);
        return;
    }
	
    $uploadResult = $client->UploadDocument(array("data"=>$data, "attributes"=>$attributes));
    $idSelfCite = $uploadResult->UploadDocumentResult->Uploaded[0]->Id;
	
    $client->CheckDocument(array("docId" => $idSelfCite));

    // Get current status of the last check
    $status = $client->GetCheckStatus(array("docId" => $idSelfCite));

    // The cycle of waiting for the end of the check
    while ($status->GetCheckStatusResult->Status === "InProgress")
    {
        sleep($status->GetCheckStatusResult->EstimatedWaitTime * 0.1);
        $status = $client->GetCheckStatus(array("docId" => $idSelfCite));
    }

    // Get brief report
    $report = $client->GetReportView(array("docId" => $idSelfCite));
	#There should be a full self-citation
    echo("Report SelfCite:" . $report->GetReportViewResult->Summary->DetailedScore->SelfCite);

}


function get_ver_rep_filename($id, $reportOptions)
{
    $author = '';

    if (!is_null($reportOptions))
        if (!IsNullOrEmptyString($reportOptions['Author']))
            $author = '_' . $reportOptions['Author'];

    $curDate = date("Ymd");

    return sprintf("Certificate_%s_%s%s.pdf", $id->Id, $curDate, $author);
}

function IsNullOrEmptyString($str){
    return (!isset($str) || trim($str) === '');
}

// soap_debug($client);
try {
    // simple_check("test_wiki.pdf");
    // enumerate_documents();
    // enumerate_index();
    // get_web_report("test_wiki.pdf");
    // folders_methods("test_wiki.pdf", "test_wiki.pdf");
    // storage_methods("test_wiki.pdf", "test_wiki.pdf");
    // export_report_to_pdf("test_wiki.pdf");
    // get_tariff_info();
    // get_verification_report("test_wiki.pdf");
     enumerate_reports();
    // get_bibliography("test.txt");
    // selfcite_check("test_wiki.pdf");
	
} catch (SoapFault $e) {
    var_dump($e->getCode());
    var_dump($e);
    soapDebug($client);
}

?>