# coding: utf-8
import os
import suds
import time
import base64
import urllib
import io
import base64
import sys
import datetime

ANTIPLAGIAT_URI = "https://testapi.antiplagiat.ru"

# Create client service(https)
LOGIN = "testapi@antiplagiat.ru"
PASSWORD = "testapi"
COMPANY_NAME = "testapi"
APICORP_ADDRESS = "api.antiplagiat.ru:44902"
client = suds.client.Client("https://%s/apiCorp/%s?singleWsdl" % (APICORP_ADDRESS, COMPANY_NAME),
                            username=LOGIN,
                            password=PASSWORD)

import logging
logging.basicConfig(level=logging.INFO)
# logging.getLogger("suds.client").setLevel(logging.DEBUG)
# logging.getLogger("suds.transport").setLevel(logging.DEBUG)
# logging.getLogger("suds.xsd.schema").setLevel(logging.DEBUG)
# logging.getLogger("suds.wsdl").setLevel(logging.DEBUG)

# Preparation of the description of the uploaded file.
def get_doc_data(filename):
    data = client.factory.create("DocData")
    data.Data = base64.b64encode(open(filename, "rb").read()).decode()
    data.FileName = os.path.splitext(filename)[0]
    data.FileType = os.path.splitext(filename)[1]
    data.ExternalUserID = "ivanov"
    return data

# An example of the most common scenario of the document check.
def simple_check(filename):
    print("SimpleCheck filename=" + filename)
    # Description of the uploaded file
    data = get_doc_data(filename)

    docatr = client.factory.create("DocAttributes")
    personIds = client.factory.create("PersonIDs")
    personIds.CustomID = "original"

    arr = client.factory.create("ArrayOfAuthorName")

    author = client.factory.create("AuthorName")
    author.OtherNames = "Ivan"
    author.Surname = "Ivanov"
    author.PersonIDs = personIds

    arr.AuthorName.append(author) 
    
    docatr.DocumentDescription.Authors = arr

    # File uploading
    try:
        uploadResult = client.service.UploadDocument(data, docatr)
    except Exception:
        raise

    # Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    id = uploadResult.Uploaded[0].Id

    try:
        # Send to check using all available searching modules 
        client.service.CheckDocument(id)
		# Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
		#client.service.CheckDocument(id, ["wikipedia", COMPANY_NAME])
    except suds.WebFault:
        raise

    # Get current status of the last check
    status = client.service.GetCheckStatus(id)

    # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(status.EstimatedWaitTime*0.1)
        status = client.service.GetCheckStatus(id)

    # Check failed
    if status.Status == "Failed":
        print(u"While checking the document %s an error occured: %s" % (filename, status.FailDetails))

    # Get brief report
    report = client.service.GetReportView(id)

    print("Report Summary: %0.2f%%" % (report.Summary.Score,))
    for checkService in report.CheckServiceResults:
        # Information about each search module 
        print("Check service: %s, Score.White=%0.2f%% Score.Black=%0.2f%%" %
                (checkService.CheckServiceName,
                 checkService.ScoreByReport.Legal, checkService.ScoreByReport.Plagiarism))
        if not hasattr(checkService, "Sources"):
            continue
        for source in checkService.Sources:
            # Information about each found source
            print('\t%s: Score=%0.2f%%(%0.2f%%), Name="%s" Author="%s" Url="%s"' %
                (source.SrcHash, source.ScoreByReport, source.ScoreBySource,
                 source.Name, source.Author, source.Url))

    # Get full report
    options = client.factory.create("ReportViewOptions")
    options.FullReport = True
    options.NeedText = True
    options.NeedStats = True
    options.NeedAttributes = True
    fullreport = client.service.GetReportView(id, options)
    if fullreport.Details.CiteBlocks:
        # Find the biggest block of reuses and display it 
        maxBlock = max(fullreport.Details.CiteBlocks, key=lambda x: x.Length)
        print(u"Max block length=%s Source=%s text:\n%s..." % (maxBlock.Length, maxBlock.SrcHash,
               fullreport.Details.Text[maxBlock.Offset:maxBlock.Offset + min(maxBlock.Length, 200)]))
			   
	print(u"Author Surname=%s OtherNames=%s CustomID=%s" % (fullreport.Attributes.DocumentDescription.Authors.AuthorName[0].Surname,
		fullreport.Attributes.DocumentDescription.Authors.AuthorName[0].OtherNames,
		fullreport.Attributes.DocumentDescription.Authors.AuthorName[0].PersonIDs.CustomID))

def incorrect_upload(filename):
    print("IncorrectUpload filename=" + filename)
    # Description of the uploaded file
    data = client.factory.create("DocData")
    data.Data = base64.b64encode(open(filename).read())
    data.FileName = os.path.splitext(filename)[0]
    data.FileType = ".tre"

    # File uploading
    try:
        uploadResult = client.service.UploadDocument(data)
    except suds.WebFault as e:
        if e.fault.faultcode == "a:InvalidArgumentException":
            # This file cannot be downloaded. The specific reason is indicated in the field Message.
            # Repeating the call with the same parameters is pointless, the result will be the same.
            raise Exception(u"File can't be uploaded: " + e.fault.faultstring)
        raise
        # The problem is not related to a specific file, it makes sense to try again later

# Enumeration of all received reports
def enumerate_reports():
    print("Enumerate Reports")
    # selecting user documents with an ID in the external system "ivanov"
    opts = client.factory.create("EnumerateReportsOptions")
    opts.ExternalUserID = "ivanov"
    opts.Count = 10
    opts.Skip = 0
    # Get the first pack of reports, sorting is always reverse chronological, the report of the last uploaded document will be the first
    reps = client.service.EnumerateReportInfos(opts)
    # Report counter
    i = 0
    # The EnumerateReportInfos function returns the results of the check in pack. An empty pack means that the enumeration has ended.
    while (reps and len(reps) > 0):
        for info in reps:
            i += 1
            print("%d  DocName: %s\n   Status: %s" % (i, info.DocumentInfo.Attributes.Name, info.CheckStatus.Status))
            if info.CheckStatus.Status == "Ready":
                print("   %s, %s" % (info.CheckStatus.Summary.Score, ANTIPLAGIAT_URI + info.CheckStatus.Summary.ReportWebId))
        # Get the next pack of reports
        opts.Skip = i
        reps = client.service.EnumerateReportInfos(opts)

# Enumeration of all uploaded documents
def enumerate_documents():
    print("Enumerate Documents")
    # Get the first pack of documents
    docs = client.service.EnumerateDocuments(None)
    # Document counter
    i = 0
    # The EnumerateDocuments function returns IDs in packs. An empty pack means that the search has ended.
    while (docs and len(docs) > 0):
        for id in docs:
            i += 1
            # We add every fifth document to the index
            if (i % 5) == 0:
                client.service.SetIndexState(id, "Indexed")

            # We add an attribute to every third document
            if (i % 3) == 0:
                docnum = client.factory.create("CustomAttribute")
                docnum.AttrName = "docnum"
                docnum.AttrValue = str(i)
                docatr = client.factory.create("DocAttributes")
                docatr.Custom = [docnum]

                client.service.UpdateDocumentAttributes(id, docatr)

        # Get the next pack of document IDs
        docs = client.service.EnumerateDocuments(docs[-1])

    print("Total documents count: %s (%s)" % (i, client.service.GetCompanyStats().TotalCount))

# Enumeration of all documents added to the index
def enumerate_index():
    print("EnumerateIndex")
    # When calling EnumerateDocuments, the options indicate that only documents added to the index are required
    enumerateOptions = client.factory.create("EnumerateDocumentsOptions")
    enumerateOptions.AddedToIndex = True
    docs = client.service.EnumerateDocuments(None, enumerateOptions)
    # Document counter
    i = 0
    # The EnumerateDocuments function returns IDs in packs. An empty pack means that the search has ended.
    while (docs and len(docs) > 0):
        for id in docs:
            i += 1
            # We delete every second document from the index
            if (i % 2) == 0:
                client.service.SetIndexState(id, "None")
        # Get next pack of document IDs
        docs = client.service.EnumerateDocuments(docs[-1], enumerateOptions)

    print("Total indexed documents count: %s (%s)" % (i, client.service.GetCompanyStats().AddedToIndexCount))

# Check the document, get the link to the report on the "Antiplagiat" website
def get_web_report(filename):
    # Description of the uploaded file
    data = get_doc_data(filename)

    # File upload
    uploadResult = client.service.UploadDocument(data)

    # Document ID. If the archive is not being uploaded, then the list of uploaded documents will consist of one element.
    id = uploadResult.Uploaded[0].Id
    # Send to check using all available searching modules 
    client.service.CheckDocument(id)

    # Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
	#client.service.CheckDocument(id, ["wikipedia", COMPANY_NAME])

    # Get current status of the last check
    status = client.service.GetCheckStatus(id)

    # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(status.EstimatedWaitTime)
        status = client.service.GetCheckStatus(id)

    # Check failed
    if status.Status == "Failed":
        print("While checking the document %s an error occurred: %s" % (filename, status.FailDetails))
        return

    # Get link to the full report on the "Antiplagiat" site
    print("Full Report: " + ANTIPLAGIAT_URI + status.Summary.ReportWebId)

    # Get link to the brief report on the "Antiplagiat" site
    print("Short Report: " + ANTIPLAGIAT_URI + status.Summary.ShortReportWebId)

    # Get link to the read-only report on the "Antiplagiat" site
    print("Readonly Report: " + ANTIPLAGIAT_URI + status.Summary.ReadonlyReportWebId)

# Methods for working with folders
def folders_methods(filename1, filename2):
    print("folders_methods")

    email = "testapi@antiplagiat.ru"

    # User creates folder "New Folder"
    folderId = client.service.AddFolder(email, "New folder")

    # User renames it to "Documents"
    client.service.RenameFolder(email, folderId, "Documents")

    # Description of folder creation options.
    folderOptions = client.factory.create("FolderOptions")
    folderOptions.ParentId = folderId

    # User creates in the folder "Documents" a new folder "Important"
    importantFolderId = client.service.AddFolder(email, "Important", folderOptions)

    # Description of the first uploaded file
    data1 = get_doc_data(filename1)

    # Description of the first file upload options
    uploadOptions1 = client.factory.create("UploadOptions")
    uploadOptions1.FolderId = folderId
    uploadOptions1.FromUser = email

    # User uploads file fileName1 to the folder "Documents"
    client.service.UploadDocument(data1, None, uploadOptions1)

    # Description of the second uploaded file
    data2 = get_doc_data(filename2)

    # Description of the second file upload options
    uploadOptions2 = client.factory.create("UploadOptions")
    uploadOptions2.FolderId = folderId
    uploadOptions2.FromUser = email

    # ПUser uploads file fileName2 to the folder "Important"
    client.service.UploadDocument(data2, None, uploadOptions2)

    # User creates folder "Trash"
    trashFolderId = client.service.AddFolder(email, "Trash")

    # Description of documents enumeration options
    enumerateDocumentsOptions1 = client.factory.create("EnumerateDocumentsOptions")
    enumerateDocumentsOptions1.FromUser = email

    # The user gets the IDs of all his documents
    docIds = client.service.EnumerateDocuments(None, enumerateDocumentsOptions1)

    # User moves his documents to the folder "Trash"
    client.service.MoveDocuments(email, trashFolderId, docIds)

    # User gets a folder tree
    folderTree = client.service.GetFolders(email)

    print("FolderTree:")

    print("\nTop level:")
    print("Name: %s" % (folderTree.Name))

    print("\nNext level:")

    for folder in folderTree.Children[0]:
        print("Name: %s" % (folder.Name))

    print("\nGet documents from \"Trash\"")

    # Description of documents enumeration options
    enumerateDocumentsOptions2 = client.factory.create("EnumerateDocumentsOptions")
    enumerateDocumentsOptions2.InStorage = False
    enumerateDocumentsOptions2.FolderId = trashFolderId
    enumerateDocumentsOptions2.FromUser = email

    # User gets his documents from the folder "Trash"
    trashDocs = client.service.EnumerateDocuments(None, enumerateDocumentsOptions2)

    print("Documents count: %s" % (len(trashDocs)))

    # User deletes folders "Documents" and "Trash"
    client.service.DeleteFolder(email, folderId)
    client.service.DeleteFolder(email, trashFolderId)

# Methods for working with the storage.
def storage_methods(filename1, filename2):
    print("storage_methods")

    # User creates folder "New Folder" in the storage
    folderId = client.service.AddFolder(None, "New folder")

    # User renames it into "Documents"
    client.service.RenameFolder(None, folderId, "Documents")

    # Description of folder creation options
    folderOptions = client.factory.create("FolderOptions")
    folderOptions.ParentId = folderId

    # User creates new folder "Important" in the folder "Documents"
    importantFolderId = client.service.AddFolder(None, "Important", folderOptions)

    # Description of the first uploaded file
    data1 = get_doc_data(filename1)

    # Description of the first file upload options
    uploadOptions1 = client.factory.create("UploadOptions")
    uploadOptions1.FolderId = folderId
    uploadOptions1.ToStorage = True

    # User uploads file fileName1 into the folder "Documents" 
    client.service.UploadDocument(data1, None, uploadOptions1)

    # Description of the second uploaded file
    data2 = get_doc_data(filename2)

    # Description of the second file upload options
    uploadOptions2 = client.factory.create("UploadOptions")
    uploadOptions2.FolderId = folderId
    uploadOptions2.ToStorage = True

    # User uploads file fileName2 into the folder "Important"
    client.service.UploadDocument(data2, None, uploadOptions2)

    # User creates folder "Trash" in the storage
    trashFolderId = client.service.AddFolder(None, "Trash")

    # The user gets the IDs of all documents from the storage
    enumerateDocumentsOptions = client.factory.create("EnumerateDocumentsOptions")
    enumerateDocumentsOptions.InStorage = True
    docIds = client.service.EnumerateDocuments(None, enumerateDocumentsOptions)

    # The user moves all documents to the folder "Trash"
    client.service.MoveDocuments(None, trashFolderId, docIds)

    # The user gets a tree of storage folders
    folderTree = client.service.GetFolders(None)

    print("FolderTree:")

    print("\nTop level:")
    print("Name: %s" % (folderTree.Name))

    print("\nNext level:")

    for folder in folderTree.Children[0]:
        print("Name: %s" % (folder.Name))

    print("\nGet documents from \"Trash\"")

    # Description of documents enumeraion options
    enumerateDocumentsOptions2 = client.factory.create("EnumerateDocumentsOptions")
    enumerateDocumentsOptions2.InStorage = True
    enumerateDocumentsOptions2.FolderId = trashFolderId

    # User gets the documents from the folder "Trash" in the storage
    trashDocs = client.service.EnumerateDocuments(None, enumerateDocumentsOptions2)

    print("Documents count: %s" % (len(trashDocs)))

    # User deletes folders "Documents" and "Trash"
    client.service.DeleteFolder(None, folderId)
    client.service.DeleteFolder(None, trashFolderId)

# Getting information about the current tariff.
def get_tariff_info():
    print("GetTariffInfo")

    # Get information about the current tariff
    tariffInfo = client.service.GetTariffInfo()

    print("Tariff name: %s" % (tariffInfo.Name))
    print("Tariff subscription date: %s" % (tariffInfo.SubscriptionDate))
    print("Tariff expiration date: %s" % (tariffInfo.ExpirationDate))
    print("Tariff total checks count: %s" % (tariffInfo.TotalChecksCount))
    print("Tariff remained checks count: %s" % (tariffInfo.RemainedChecksCount))

    print("\nAvailable check services:")

    for checkService in tariffInfo.CheckServices[0]:
        print("%s (%s)" % (checkService.Code, checkService.Description))

# Check the document, get the link to the pdf-report on the "Antiplagiat" site
def export_report_to_pdf(filename):
    print("export_report_to_pdf")

    # Description of the file being uploaded
    data = get_doc_data(filename)

    # File uploading
    try:
        uploadResult = client.service.UploadDocument(data)
    except Exception:
        raise

    # Document ID.  If the archive is not being downloaded, then 
    # the list of downloaded documents will consist of one element
    id = uploadResult.Uploaded[0].Id

    try:
        # Send to check using all available searching modules 
        client.service.CheckDocument(id)
		# Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
		#client.service.CheckDocument(id, ["wikipedia", COMPANY_NAME])
    except Exception:
        raise

    # Get current status of the last check
    status = client.service.GetCheckStatus(id)

     # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(max(status.EstimatedWaitTime, 10) * 0.1)
        status = client.service.GetCheckStatus(id)

    # Check failed
    if status.Status == "Failed":
        print("While checking the document %s an error occured: %s" % (filename, status.FailDetails))

    # Request generation of the last full report in PDF format.
    exportReportInfo = client.service.ExportReportToPdf(id)

    while exportReportInfo.Status == "InProgress":
        time.sleep(max(exportReportInfo.EstimatedWaitTime, 10) * 0.1)
        exportReportInfo = client.service.ExportReportToPdf(id)

    # Report generation failed.
    if exportReportInfo.Status == "Failed":
        print("While generating the report for the document %s an error occured: %s" % (filename, exportReportInfo.FailDetails))

    # Get a link to the report on the "Antiplagiat" website
    # Please pay attention that it is not guaranteed that this link will work forever, it may stop working at any time,
    # therefore, you cannot give it to the user. You need to download a pdf for yourself and then manage its lifetime
    downloadLink = ANTIPLAGIAT_URI + exportReportInfo.DownloadLink
    print("PDF full report (number = %s): %s" % (exportReportInfo.ReportNum, downloadLink))

    # Options for generating a brief report with the number 1 in PDF format.
    options = client.factory.create("ExportReportOptions")
    options.ReportNum = 1
    options.ShortReport = True

    # Request the generation of a PDF report with the specified options.
    exportReportInfo = client.service.ExportReportToPdf(id, options)

    # The cycle of waiting for report generation
    while exportReportInfo.Status == "InProgress":
        time.sleep(max(exportReportInfo.EstimatedWaitTime, 10) * 0.1)
        exportReportInfo = client.service.ExportReportToPdf(id, options)

    # Report generation failed.
    if exportReportInfo.Status == "Failed":
        print("While generating the pdf-report fot the document %s an error occured" % (filename))

    # Get a link to the report on the "Antiplagiat" website
    # Please pay attention that it is not guaranteed that this link will work forever, it may stop working at any time,
    # therefore, you cannot give it to the user. You need to download a pdf for yourself and then manage its lifetime
    downloadLink = ANTIPLAGIAT_URI + exportReportInfo.DownloadLink
    print("PDF short report (number = %s): %s" % (exportReportInfo.ReportNum, downloadLink))

# An example of getting a certificate for the checked file
def get_verification_report(filename):
    print("get_verification_report")

    # Description of the file being uploaded
    data = get_doc_data(filename)

    # File uploading
    uploadResult = client.service.UploadDocument(data)

    # Document ID. If the archive is not being downloaded, then the list of downloaded documents will consist of one element
    id = uploadResult.Uploaded[0].Id

    # Send to check using all available searching modules 
    client.service.CheckDocument(id)
	# Send to check using only own collection and "wikipedia" searching module. To get all searchilg modules list use example get_tariff_info()
	#client.service.CheckDocument(id, ["wikipedia", COMPANY_NAME])

    # Get current status of the last check
    status = client.service.GetCheckStatus(id)

    # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(status.EstimatedWaitTime)
        status = client.service.GetCheckStatus(id)

    # Check failed.
    if status.Status == "Failed":
        print("При проверке документа %s произошла ошибка: %s" % (filename, status.FailDetails))
        return

    try:
        #You can download certificate with or without filled fields
        # To fill the fields, you need to create a certificate options object with the desired property values
        reportOptions = client.factory.create("VerificationReportOptions")
        reportOptions.Author = u"Ivanov I.I." # Full name of the document's author
        reportOptions.Department = u"Faculty of General and Applied Physics" # Faculty (structural subdivision)
        reportOptions.ShortReport = True # Is a link to the summary brief required? (qr code)
        reportOptions.Type = u"Thesis" # Type of work
        reportOptions.Verifier = u"Petrov P.P." # Full name of the verifier
        reportOptions.Work = u"Coherent spin dynamics of a two-dimensional electron gas"  # Name of the work

        # With filled fields
        reportWithFields = client.service.GetVerificationReport(id, reportOptions)
        # Without filled fields
        # reportWithoutFields = client.service.GetVerificationReport(id)

        # writing to file
        decoded = base64.b64decode(reportWithFields)
        fileName = get_report_name(id, reportOptions)
        f = open(fileName, 'wb')
        f.write(decoded)
    except suds.WebFault as e:
        if e.fault.faultcode == "a:InvalidArgumentException":
            raise Exception(u"The document does not have a report/closed report or None was passed as the id in GetVerificationReport: " + e.fault.faultstring)
        if e.fault.faultcode == "a:DocumentIdException":
            raise Exception(u"Invalid DocumentId is passed" + e.fault.faultstring)
        raise
        # The problem is not related to the parameters being passed, it makes sense to try again later


def get_report_name(id, reportOptions):
    author = u''

    if reportOptions is not None:
        if reportOptions.Author:
            author = '_' + reportOptions.Author

    curDate = datetime.datetime.today().strftime('%Y%m%d')
    return u'Certificate_%s_%s%s.pdf' % (id.Id, curDate, author)

# Scenario of checking on self-citation.
def selfcite_check(filename):
    print("SelfCiteCheck filename=" + filename)
    # Description of the file being uploaded
    data = get_doc_data(filename)

    docatr = client.factory.create("DocAttributes")
    personIds = client.factory.create("PersonIDs")
    personIds.CustomID = "original"

    arr = client.factory.create("ArrayOfAuthorName")

    author = client.factory.create("AuthorName")
    author.OtherNames = "Иван Иванович"
    author.Surname = "Иванов"
    author.PersonIDs = personIds

    arr.AuthorName.append(author)
    
    docatr.DocumentDescription.Authors = arr
    opts = client.factory.create("UploadOptions")
    opts.AddToIndex = True

    # File uploading
    try:
        uploadResult = client.service.UploadDocument(data, docatr, opts)
    except Exception:
        raise

    # Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    id = uploadResult.Uploaded[0].Id

    try:
        # Send to check using all available searching modules
        client.service.CheckDocument(id)
    except suds.WebFault:
        raise

    # Get current status of the last check
    status = client.service.GetCheckStatus(id)

    # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(status.EstimatedWaitTime*0.1)
        status = client.service.GetCheckStatus(id)

    # Check failed
    if status.Status == "Failed":
        print(u"При проверке документа %s произошла ошибка: %s" % (filename, status.FailDetails))
		
    # File uploading
    try:
        uploadResult = client.service.UploadDocument(data, docatr)
    except Exception:
        raise

    # Document ID. If the archive is not being uploaded, then the list of downloaded documents will consist of one element.
    idSelfCite = uploadResult.Uploaded[0].Id

    try:
        # Send to check using all available searching modules
        client.service.CheckDocument(idSelfCite)
    except suds.WebFault:
        raise

    # Get current status of the last check
    status = client.service.GetCheckStatus(idSelfCite)

    # The cycle of waiting for the end of the check
    while status.Status == "InProgress":
        time.sleep(status.EstimatedWaitTime*0.1)
        status = client.service.GetCheckStatus(idSelfCite)
		

    # Get brief report
    report = client.service.GetReportView(idSelfCite)
	#There should be a full self-citation
    print("Report SelfCite: %0.2f%%" % (report.Summary.DetailedScore.SelfCite))


# simple_check("test_wiki.pdf")
# enumerate_documents()
# incorrect_upload("test_wiki.pdf")
# enumerate_index()
# get_web_report(r"test_wiki.pdf")
# folders_methods("test_wiki.pdf", "test_wiki.pdf")
# storage_methods("test_wiki.pdf", "test_wiki.pdf")
# export_report_to_pdf("test_wiki.pdf")
# get_tariff_info()
# get_verification_report("test_wiki.pdf")
# enumerate_reports()
# selfcite_check("test_wiki.pdf")
